#
# bootloader_diskorder_text.py: screen to allow user to set disk order
#
# Copyright 2009 Oracle Inc.
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
#
# You should have received a copy of the GNU Library Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

from snack import *
from constants import *
from constants_text import *
from rhpl.translate import _
from flags import flags
import string, iutil, bootloader, partedUtils, logging

log = logging.getLogger("anaconda")

class BootloaderDiskOrderWindow:

    def __init__(self):
        self.driveOrder = None
        self.disks = None

    def __call__(self, screen, anaconda):
        log.info("Entering bootloader disk order window")
        self.disks = anaconda.id.diskset.disks
        self.driveOrder = anaconda.id.bootloader.drivelist

        log.info("Disks is %s" %(self.disks))
        log.info("Drive order is %s" %(self.driveOrder))
        log.info("Device is %s" %(anaconda.id.bootloader.getDevice()))

        default = 0
        while 1:
            locations = []
            for drive in self.driveOrder:
                locstr = "/dev/%s" % (drive,)
                # if we have it in the diskset, get the size and type of drive
                if self.disks.has_key(drive):
                    size = partedUtils.getDeviceSizeMB(self.disks[drive].dev)
                    locstr += "  %8.0f MB  %s" %(size,self.disks[drive].dev.model)
                locations.append(locstr)
                

            (rc, sel) = ListboxChoiceWindow (screen, _("Edit Drive Order"),
                         _("Arrange the drives to be in the same "
                             "order as used by the BIOS. Changing "
                             "the drive order may be useful if you "
                             "have multiple SCSI adapters or both SCSI "
                             "and IDE adapters and want to boot from "
                             "the SCSI device.\n\n"
                             "Changing the drive order will change "
                             "where the installation program "
                             "locates the Master Boot Record (MBR)."),
                         locations, default = default, scroll = 1, height = 5,
                         buttons = [ TEXT_MOVEUP_BUTTON, TEXT_MOVEDOWN_BUTTON, TEXT_BACK_BUTTON ],
                         help = "bootloaderlocation")

            if rc == TEXT_BACK_CHECK:
                anaconda.id.bootloader.setDevice(self.driveOrder[0])
                return INSTALL_BACK
            else:
                if rc == TEXT_MOVEDOWN_CHECK:
                    if not sel == len(self.driveOrder) - 1:
                        drive = self.driveOrder.pop(sel)
                        self.driveOrder.insert(sel + 1, drive)
                        default = sel + 1 
                elif rc == TEXT_MOVEUP_CHECK:
                    if sel >= 1:
                        drive = self.driveOrder.pop(sel)
                        self.driveOrder.insert(sel - 1, drive)
                        default = sel - 1 

